import customtkinter as ctk
from tkinter import messagebox
from PIL import Image
from utils.api_requests import login_api


def login_frame(parent, switch_func, API_URL):
    # Overall container
    container = ctk.CTkFrame(parent, fg_color="#F3F4F6")  # Light gray background
    container.grid_columnconfigure(0, weight=1)
    container.grid_columnconfigure(1, weight=1)
    container.grid_rowconfigure(0, weight=1)

    # Left image frame
    left_frame = ctk.CTkFrame(container, fg_color="transparent")
    left_frame.grid(row=0, column=0, sticky="nsew")

    image_path = "../../app/static/front_end_img/login.jpg"
    img = ctk.CTkImage(light_image=Image.open(image_path), size=(800, 800))
    image_label = ctk.CTkLabel(left_frame, image=img, text="")
    image_label.place(relwidth=1, relheight=1)

    # Right login frame
    right_frame = ctk.CTkFrame(container, fg_color="white", corner_radius=20)
    right_frame.grid(row=0, column=1, sticky="nsew", padx=50, pady=100)
    right_frame.grid_columnconfigure(0, weight=1)

    # Login Function
    def login():
        email = entry_email.get()
        password = entry_password.get()

        if not email or not password:
            messagebox.showwarning("Input Error", "Both fields are required!")
            return

        status_code, response_data = login_api(email, password, API_URL)

        if status_code == 200:
            access_token = response_data.get("access_token")
            messagebox.showinfo("Login Successful", f"Welcome back, {email}!")
            switch_func("dashboard", access_token)
        else:
            messagebox.showerror(
                "Login Failed", response_data.get("detail", "Invalid credentials")
            )

    # Title
    ctk.CTkLabel(
        right_frame,
        text="Login",
        font=ctk.CTkFont("Helvetica", size=26, weight="bold"),
        text_color="#111827",
    ).pack(pady=(20, 10))

    # Email
    ctk.CTkLabel(
        right_frame, text="Email", font=("Helvetica", 14), text_color="#374151"
    ).pack(pady=(10, 5))
    entry_email = ctk.CTkEntry(
        right_frame, height=40, corner_radius=10, placeholder_text="Enter your email"
    )
    entry_email.pack(pady=5, padx=20, fill="x")

    # Password
    ctk.CTkLabel(
        right_frame, text="Password", font=("Helvetica", 14), text_color="#374151"
    ).pack(pady=(10, 5))
    entry_password = ctk.CTkEntry(
        right_frame,
        height=40,
        show="*",
        corner_radius=10,
        placeholder_text="Enter your password",
    )
    entry_password.pack(pady=5, padx=20, fill="x")

    # Login Button
    ctk.CTkButton(
        right_frame,
        text="Login",
        command=login,
        corner_radius=10,
        height=45,
        font=("Helvetica", 14),
        fg_color="#2563EB",
        hover_color="#1E40AF",
    ).pack(pady=20, padx=20, fill="x")

    # Register Redirect
    ctk.CTkButton(
        right_frame,
        text="Don't have an account? Register",
        command=lambda: switch_func("register"),
        fg_color="transparent",
        hover_color="#E5E7EB",
        text_color="#2563EB",
    ).pack(pady=(5, 20))

    return container
